/*

Java Code for refreshing the LDAP graph in BOXI.

This implements the IProgramBaseEx class which requests the BOXI logon credentials
directly from BOXI meaning we do not need to pass logon details to this.

The code works by forcing a refresh, via a commit. This commit notifies the CMS that a 
change has been made, which in turn refreshes the BOXI LDAP graph.

Version History
---------------
Stephen Cox	14 Nov 2007
Adapted code sent from Business Objects to make fit for purpose for scheduling in BOXI

*/

import java.util.Date;
import com.crystaldecisions.sdk.exception.SDKException;
import com.crystaldecisions.sdk.framework.CrystalEnterprise;
import com.crystaldecisions.sdk.framework.IEnterpriseSession;
import com.crystaldecisions.sdk.occa.infostore.IInfoObjects;
import com.crystaldecisions.sdk.occa.infostore.IInfoObject;
import com.crystaldecisions.sdk.occa.infostore.IInfoStore;
import com.crystaldecisions.sdk.plugin.authentication.ldap.IsecLDAP;
import com.crystaldecisions.sdk.plugin.desktop.program.IProgramBaseEx;


public class UpdatePlugin implements IProgramBaseEx{

  public void run(IEnterpriseSession enterpriseSession, IInfoStore infoStore, IInfoObject infoObject, String objectId, String[] args) throws SDKException {
		
    try {
      System.out.println("Scheduled Java App for Update LDAP");
      System.out.println("CMS is " + enterpriseSession.getCMSName());
      System.out.println("Querying for the plugin");

      //Query for any object in the CMS.
      String lQuery = "SELECT TOP 1 * " 
                    + "FROM CI_SYSTEMOBJECTS "
                    + "WHERE SI_NAME='secLDAP'";
		
      IInfoObjects lInfoObjects = (IInfoObjects) infoStore.query(lQuery);
			
      if (lInfoObjects.size() > 0) {
        System.out.println("A plugin was found");
        IsecLDAP lPlugin = (IsecLDAP) lInfoObjects.get(0);
			
        System.out.println("Old value: " + lPlugin.properties().getProperty("SI_UPDATE_TS").getValue());
			
        lPlugin.properties().getProperty("SI_UPDATE_TS").setValue(new Date());
			
        System.out.println("Commiting the value");
        infoStore.commit(lInfoObjects);
			
        }//if
      
      else{
        System.out.println("no plugin was found using SQL [" + lQuery + "]");
        }//else	

      }//try 
		
      catch (SDKException lException) {
        lException.printStackTrace();
        }//catch
	
    }//run

  }//class
